==> perl-5.13.5.tar.gz: perl-5.13.5/cpan/Unicode-Collate/Collate/Locale/wo.pl <==
+{
# eng doesn't require tailoring
   entry => <<'ENTRY', # for DUCET v5.2.0
00E0      ; [.1210.0020.0002.00E0] # LATIN SMALL LETTER A WITH GRAVE
0061 0300 ; [.1210.0020.0002.00E0] # LATIN SMALL LETTER A WITH GRAVE
00C0      ; [.1210.0020.0008.00C0] # LATIN CAPITAL LETTER A WITH GRAVE
0041 0300 ; [.1210.0020.0008.00C0] # LATIN CAPITAL LETTER A WITH GRAVE
00E9      ; [.126C.0020.0002.00E9] # LATIN SMALL LETTER E WITH ACUTE
0065 0301 ; [.126C.0020.0002.00E9] # LATIN SMALL LETTER E WITH ACUTE
00C9      ; [.126C.0020.0008.00C9] # LATIN CAPITAL LETTER E WITH ACUTE
0045 0301 ; [.126C.0020.0008.00C9] # LATIN CAPITAL LETTER E WITH ACUTE
00EB      ; [.126D.0020.0002.00EB] # LATIN SMALL LETTER E WITH DIAERESIS
0065 0308 ; [.126D.0020.0002.00EB] # LATIN SMALL LETTER E WITH DIAERESIS
00CB      ; [.126D.0020.0008.00CB] # LATIN CAPITAL LETTER E WITH DIAERESIS
0045 0308 ; [.126D.0020.0008.00CB] # LATIN CAPITAL LETTER E WITH DIAERESIS
00F1      ; [.136E.0020.0002.00F1] # LATIN SMALL LETTER N WITH TILDE
006E 0303 ; [.136E.0020.0002.00F1] # LATIN SMALL LETTER N WITH TILDE
00D1      ; [.136E.0020.0008.00D1] # LATIN CAPITAL LETTER N WITH TILDE
004E 0303 ; [.136E.0020.0008.00D1] # LATIN CAPITAL LETTER N WITH TILDE
00F3      ; [.138F.0020.0002.00F3] # LATIN SMALL LETTER O WITH ACUTE
006F 0301 ; [.138F.0020.0002.00F3] # LATIN SMALL LETTER O WITH ACUTE
00D3      ; [.138F.0020.0008.00D3] # LATIN CAPITAL LETTER O WITH ACUTE
004F 0301 ; [.138F.0020.0008.00D3] # LATIN CAPITAL LETTER O WITH ACUTE
ENTRY
};

==> perl-5.13.6.tar.gz: perl-5.13.6/cpan/Unicode-Collate/Collate/Locale/wo.pl <==
+{
# eng doesn't require tailoring
   entry => <<'ENTRY', # for DUCET v5.2.0
00E0      ; [.1210.0020.0002.00E0] # LATIN SMALL LETTER A WITH GRAVE
0061 0300 ; [.1210.0020.0002.00E0] # LATIN SMALL LETTER A WITH GRAVE
0061 0340 ; [.1210.0020.0002.00E0] # LATIN SMALL LETTER A WITH GRAVE
00C0      ; [.1210.0020.0008.00C0] # LATIN CAPITAL LETTER A WITH GRAVE
0041 0300 ; [.1210.0020.0008.00C0] # LATIN CAPITAL LETTER A WITH GRAVE
0041 0340 ; [.1210.0020.0008.00C0] # LATIN CAPITAL LETTER A WITH GRAVE
00E9      ; [.126C.0020.0002.00E9] # LATIN SMALL LETTER E WITH ACUTE
0065 0301 ; [.126C.0020.0002.00E9] # LATIN SMALL LETTER E WITH ACUTE
0065 0341 ; [.126C.0020.0002.00E9] # LATIN SMALL LETTER E WITH ACUTE
00C9      ; [.126C.0020.0008.00C9] # LATIN CAPITAL LETTER E WITH ACUTE
0045 0301 ; [.126C.0020.0008.00C9] # LATIN CAPITAL LETTER E WITH ACUTE
0045 0341 ; [.126C.0020.0008.00C9] # LATIN CAPITAL LETTER E WITH ACUTE
00EB      ; [.126D.0020.0002.00EB] # LATIN SMALL LETTER E WITH DIAERESIS
0065 0308 ; [.126D.0020.0002.00EB] # LATIN SMALL LETTER E WITH DIAERESIS
00CB      ; [.126D.0020.0008.00CB] # LATIN CAPITAL LETTER E WITH DIAERESIS
0045 0308 ; [.126D.0020.0008.00CB] # LATIN CAPITAL LETTER E WITH DIAERESIS
00F1      ; [.136E.0020.0002.00F1] # LATIN SMALL LETTER N WITH TILDE
006E 0303 ; [.136E.0020.0002.00F1] # LATIN SMALL LETTER N WITH TILDE
00D1      ; [.136E.0020.0008.00D1] # LATIN CAPITAL LETTER N WITH TILDE
004E 0303 ; [.136E.0020.0008.00D1] # LATIN CAPITAL LETTER N WITH TILDE
00F3      ; [.138F.0020.0002.00F3] # LATIN SMALL LETTER O WITH ACUTE
006F 0301 ; [.138F.0020.0002.00F3] # LATIN SMALL LETTER O WITH ACUTE
006F 0341 ; [.138F.0020.0002.00F3] # LATIN SMALL LETTER O WITH ACUTE
00D3      ; [.138F.0020.0008.00D3] # LATIN CAPITAL LETTER O WITH ACUTE
004F 0301 ; [.138F.0020.0008.00D3] # LATIN CAPITAL LETTER O WITH ACUTE
004F 0341 ; [.138F.0020.0008.00D3] # LATIN CAPITAL LETTER O WITH ACUTE
ENTRY
};
